@@ -10,14 +10,6 @@ import os
 import shutil
 import subprocess
 
-def garbage_collect():
-
-    # TODO (vedant) : garbage collection for NBeats is being done
-    # for kungfuai primitives. This needs to be resolved within
-    # kungfuai NBeats
-    if os.path.exists("nbeats_weights"):
-        shutil.rmtree("nbeats_weights")
-
 class AutonML(object):
     def __init__(self, input_dir, output_dir, timeout=2, numcpus=8):
         self.input_dir = os.path.abspath(input_dir)
